---
title: 결제대행사 정산 방법
category: 결제서비스 (채널설정 및 이용안내) > 이용안내 > 결제대행사 계약
seo:
  title: 결제대행사 정산 방법
  description: >-
    정산은 계약을 맺은 PG사에서 고객사로 직접 이뤄집니다. 서비스 업종/유형 등에 따라 PG사와 계약 시 정산 일자, 정산한도금액 등이
    결정됩니다. PG사 관리자 페이지에서 자세한 상점 정보를 확인하세요.
  keywords:
    - 정산
tags:
  - 공통
  - 결제대행사 계약
pgCompanies:
  - 공통
searchTags:
  - 정산한도
  - 정산주기
  - 정산방법
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="정산은 계약을 맺으신 PG사에서 고객사로 직접 이뤄집니다." title="" />

PG사와 계약을 맺으실 때 서비스 업종/유형 등에 따라  정산 일자, 정산한 도금액 등이 결정됩니다.

이미 PG사와 계약을 맺으셨다면, \
PG사의 관리자 페이지에서 자세한 상점 정보(결제수단, 수수료율, 정산 정보 등)을 확인하실 수 있습니다.

PG사와 계약 시 결정된 정보이기 때문에 포트원에서는 정산 정보를 알 수 없으며 임의로 변경하는 것도 불가합니다.
